import 'package:yumi/shared/business_logic/models/res/login_res.dart';

import 'package:yumi/shared/business_logic/models/res/country_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_google_pay_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_index_banner_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_level_config_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_product_config_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_start_page_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_top_four_with_reward_res.dart';
import 'package:yumi/shared/business_logic/models/res/version_manage_lates_review_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_version_manage_latest_res.dart';

abstract class SocialChatConfigRepository {
  ///国家列表
  Future<CountryRes> loadCountry();

  ///推荐国家列表
  Future<CountryRes> loadTopSix();

  ///app启动页.
  Future<List<SCStartPageRes>> getStartPage();

  ///系统参数配置列表.
  Future<CountryRes> getConfig();

  ///最近活动通知列表.
  Future<CountryRes> getNoticeMessage();





  ///获得客服.
  Future<CountryRes> getCustomerService();

  ///获取平台banner.
  Future<List<SCIndexBannerRes>> getBanner({List<String>?types});

  ///获取商品配置
  Future<List<SCProductConfigRes>> productConfig();

  ///谷歌内购
  Future<SCGooglePayRes> googlePay(
    String product,
    String signature,
    String purchaseData, {
    String? friendId,
  });

  ///苹果内购
  Future<SCGooglePayRes> applePay(
    String product,
    String receipt,
    String transaction, {
    String? friendId,
  });

  ///等级资源
  Future<SCLevelConfigRes> configLevel();



  ///获取APP最新版本
  Future<SCVersionManageLatestRes> versionManageLatest();

  ///获取最新及正在审核版本
  Future<VersionManageLatesReviewRes> versionManageLatestReview();

  ///获得客服
  Future<SocialChatUserProfile> customerService();

}
